Index: webrtc/media/base/testutils.cc |
diff --git a/talk/media/base/testutils.cc b/webrtc/media/base/testutils.cc |
similarity index 86% |
rename from talk/media/base/testutils.cc |
rename to webrtc/media/base/testutils.cc |
index 49a78e63ddca904793544891186e034010e3a9cd..069c49fd2581f2af7cf3e077637b11bfdb1db92d 100644 |
--- a/talk/media/base/testutils.cc |
+++ b/webrtc/media/base/testutils.cc |
@@ -1,39 +1,18 @@ |
/* |
- * libjingle |
- * Copyright 2004 Google Inc. |
+ * Copyright 2004 The WebRTC Project Authors. All rights reserved. |
* |
- * Redistribution and use in source and binary forms, with or without |
- * modification, are permitted provided that the following conditions are met: |
- * |
- * 1. Redistributions of source code must retain the above copyright notice, |
- * this list of conditions and the following disclaimer. |
- * 2. Redistributions in binary form must reproduce the above copyright notice, |
- * this list of conditions and the following disclaimer in the documentation |
- * and/or other materials provided with the distribution. |
- * 3. The name of the author may not be used to endorse or promote products |
- * derived from this software without specific prior written permission. |
- * |
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED |
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF |
- * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO |
- * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, |
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, |
- * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; |
- * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, |
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR |
- * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF |
- * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. |
+ * Use of this source code is governed by a BSD-style license |
+ * that can be found in the LICENSE file in the root of the source |
+ * tree. An additional intellectual property rights grant can be found |
+ * in the file PATENTS. All contributing project authors may |
+ * be found in the AUTHORS file in the root of the source tree. |
*/ |
-#include "talk/media/base/testutils.h" |
+#include "webrtc/media/base/testutils.h" |
#include <math.h> |
#include <algorithm> |
-#include "talk/media/base/executablehelpers.h" |
-#include "talk/media/base/rtpdump.h" |
-#include "talk/media/base/videocapturer.h" |
-#include "talk/media/base/videoframe.h" |
#include "webrtc/base/bytebuffer.h" |
#include "webrtc/base/fileutils.h" |
#include "webrtc/base/gunit.h" |
@@ -41,6 +20,10 @@ |
#include "webrtc/base/stream.h" |
#include "webrtc/base/stringutils.h" |
#include "webrtc/base/testutils.h" |
+#include "webrtc/media/base/executablehelpers.h" |
+#include "webrtc/media/base/rtpdump.h" |
+#include "webrtc/media/base/videocapturer.h" |
+#include "webrtc/media/base/videoframe.h" |
namespace cricket { |
@@ -258,18 +241,18 @@ void VideoCapturerListener::OnFrameCaptured(VideoCapturer* capturer, |
} |
} |
// Returns the absolute path to a file in the testdata/ directory. |
std::string GetTestFilePath(const std::string& filename) { |
// Locate test data directory. |
#ifdef ENABLE_WEBRTC |
rtc::Pathname path = rtc::GetExecutablePath(); |
EXPECT_FALSE(path.empty()); |
- path.AppendPathname("../../talk/"); |
+ path.AppendPathname("../../resources/"); |
#else |
rtc::Pathname path = testing::GetTalkDirectory(); |
EXPECT_FALSE(path.empty()); // must be run from inside "talk" |
#endif |
- path.AppendFolder("media/testdata/"); |
+ path.AppendFolder("media/"); |
path.SetFilename(filename); |
return path.pathname(); |
} |
@@ -258,18 +241,18 @@ void VideoCapturerListener::OnFrameCaptured(VideoCapturer* capturer, |
} |
} |
-// Returns the absolute path to a file in the testdata/ directory. |
+// Returns the absolute path to a file in the resources/ directory. |
std::string GetTestFilePath(const std::string& filename) { |
// Locate test data directory. |